@@ -19,6 +19,9 @@
 #include "kalgebrabackend.h"
 #include "kalgebrasession.h"
 
+#include "settings.h"
+#include "ui_settings.h"
+
 #include "kalgebraextensions.h"
 #include "cantor_macros.h"
 
@@ -47,6 +50,19 @@ Cantor::Backend::Capabilities KAlgebraBackend::capabilities() const
     return Cantor::Backend::Completion | Cantor::Backend::SyntaxHighlighting | Cantor::Backend::SyntaxHelp | Cantor::Backend::VariableManagement;
 }
 
+QWidget* KAlgebraBackend::settingsWidget(QWidget* parent) const
+{
+    QWidget* widget=new QWidget(parent);
+    Ui::KAlgebraSettingsBase s;
+    s.setupUi(widget);
+    return widget;
+}
+
+KConfigSkeleton* KAlgebraBackend::config() const
+{
+    return KAlgebraSettings::self();
+}
+
 KUrl KAlgebraBackend::helpUrl() const
 {
     return i18nc("the url to the documentation of KAlgebra, please check if there is a translated version and use the correct url",
